@@ -82,8 +82,7 @@ typedef enum HdAtoms
   HD_ATOM_OMAP_VIDEO_OVERLAY,
 
   HD_ATOM_MAEMO_ROTATION_TRANSITION,
-  HD_ATOM_MAEMO_SCREEN_WIDTH,
-  HD_ATOM_MAEMO_SCREEN_HEIGHT,
+  HD_ATOM_MAEMO_SCREEN_SIZE,
 
   _HD_ATOM_LAST
 } HdAtoms;
